===================================
Karbor: Application Data Protection
===================================

Introduction
============
Karbor is an OpenStack project that provides a pluggable framework for
protecting and restoring Data and Metadata that comprises an OpenStack-deployed
application - Application Data Protection as a Service.

Mission Statement
~~~~~~~~~~~~~~~~~
To protect the Data and Metadata that comprises an OpenStack-deployed
Application against loss/damage (e.g. backup, replication) by providing a
standard framework of APIs and services that allows vendors to provide plugins
through a unified interface

.. toctree::
   :maxdepth: 2


Using Karbor
============
.. toctree::
   :maxdepth: 2

   readme
   install/index
   configuration/index
   admin/index

Available Plugins
=================
.. toctree::
   :maxdepth: 2

   bank_plugins
   protectable_plugins
   protection_plugins

Contributor Docs
================

.. toctree::
   :maxdepth: 2

   contributor/index

Release Notes
=============

.. toctree::
   :maxdepth: 1

   releasenotes

Sample Files
============

.. toctree::
   :maxdepth: 1

   sample_policy

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

